<?php
/**
 * @package Cluster
 */

/**
 * Get the array of definitions for Customizer settings and controls.
 *
 * @since 1.0.0.
 *
 * @param  object $wp_customize    The Customizer instance.
 *
 * @return mixed|void
 */
function cluster_customize_get_definitions( $wp_customize ) {
	$google_fonts = cluster_all_font_choices();

	$wp_customize->add_panel( 'cluster_options_panel', array(
		'title'       => esc_html__( 'Theme Options', 'stag' ),
		'description' => esc_html__( 'Configure your theme settings', 'stag' ),
		'priority' => 999,
	) );

	$definitions = array(
		'title_tagline' => array(
			'options' => array(
				'general_text_logo' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'        => 'checkbox',
						'label'       => esc_html__( 'Plain Text Logo', 'stag' ),
						'description' => esc_html__( 'Check this box to enable a plain text logo rather than an image logo. Will use your site title.', 'stag' ),
					),
				),
				'general_custom_logo' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Image_Control',
						'label'         => esc_html__( 'Custom Logo Upload', 'stag' ),
						'description'   => esc_html__( 'Upload a logo for your theme.', 'stag' ),
					),
				),
			),
		),

		'cluster_fonts' => array(
			'title'       => esc_html__( 'Fonts', 'stag' ),
			'description' => sprintf(
				esc_html__( 'The list of Google fonts is long! You can %s before making your choices.', 'stag' ),
				sprintf(
					'<a href="%1$s" target="_blank">%2$s</a>',
					esc_url( 'https://fonts.google.com' ),
					esc_html__( 'preview', 'stag' )
				)
			),
			'priority'    => $wp_customize->get_section( 'colors' )->priority + 1,
			'options'     => array(
				'font-body' => array(
					'setting' => array(),
					'control' => array(
						'type'    => 'select',
						'choices' => $google_fonts,
						'label'   => esc_html__( 'Body', 'stag' ),
					),
				),
				'font-headers' => array(
					'setting' => array(),
					'control' => array(
						'type'    => 'select',
						'choices' => $google_fonts,
						'label'   => esc_html__( 'Headers', 'stag' ),
					),
				),
				'google-font-subset' => array(
					'setting' => array(),
					'control' => array(
						'type'        => 'select',
						'choices'     => cluster_get_google_font_subsets(),
						'label'       => esc_html__( 'Google Font Subset', 'stag' ),
						'description' => sprintf(
							esc_html__( 'Not all fonts provide each of these subsets. Please visit the %s to see which subsets are available for each font.', 'stag' ),
							sprintf(
								'<a href="%1$s" target="_blank">%2$s</a>',
								esc_url( 'https://fonts.google.com' ),
								esc_html__( 'Google Fonts website', 'stag' )
							)
						),
					),
				),
			),
		),

		'colors' => array(
			'title'       => esc_html__( 'Colors', 'stag' ),
			'description' => '',
			'priority'    => '',
			'options'     => array(
				'style_background_color' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Background', 'stag' ),
					),
				),
				'style_accent_color' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Accent', 'stag' ),
					),
				),
				'site_background_color' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Blog Background', 'stag' ),
						'description'   => esc_html__( 'Choose a default background color for the site header section.', 'stag' ),
					),
				),
				'portfolio_background_color' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Portfolio Background', 'stag' ),
						'description'   => esc_html__( 'Choose a default background color for the portfolio header section.', 'stag' ),
					),
				),
			),
		),

		'general_settings' => array(
			'title'       => esc_html__( 'General Settings', 'stag' ),
			'description' => esc_html__( 'Configure general settings of your theme and insert your analytics tracking code.', 'stag' ),
			'panel'       => 'cluster_options_panel',
			'options'     => array(
				'general_contact_email' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'type'        => 'text',
						'label'       => esc_html__( 'Contact Form Email Address', 'stag' ),
						'description' => esc_html__( 'Enter the email address where you\'d like to receive emails from the contact form, or leave blank to use admin email.', 'stag' ),
					),
				),
				'general_tracking_code' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'        => 'textarea',
						'label'       => esc_html__( 'Tracking Code', 'stag' ),
						'description' => esc_html__( 'Paste the full Google Analytics code snippet here without <script> tags.', 'stag' ),
					),
				),
				'general_footer_text' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'type'        => 'textarea',
						'label'       => esc_html__( 'Footer Copyright Text', 'stag' ),
						'description' => esc_html__( 'Enter the text to display in footer copyright area.', 'stag' ),
					),
				),
				'general_disable_seo_settings' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'        => 'checkbox',
						'label'       => esc_html__( 'Disable SEO Settings', 'stag' ),
						'description' => esc_html__( 'Enable/Disable SEO Settings on single posts and pages.', 'stag' ),
					),
				),
			),
		),

		'styling_options' => array(
			'title'       => esc_html__( 'Styling Options', 'stag' ),
			'description' => esc_html__( 'Configure the visual appearance of your theme.', 'stag' ),
			'panel'       => 'cluster_options_panel',
			'options'     => array(
				'style_main_layout' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Main Layout', 'stag' ),
						'description' => esc_html__( 'Select main content and sidebar alignment.', 'stag' ),
						'type'        => 'radio',
						'choices'     => array(
							'layout-1cf' => esc_html__( '1 Column (full)', 'stag' ),
							'layout-2cr' => esc_html__( '2 Columns (right)', 'stag' ),
							'layout-2cl' => esc_html__( '2 Columns (left)', 'stag' ),
						),
					),
				),
			),
		),

		'site_settings' => array(
			'title'       => esc_html__( 'Site Settings', 'stag' ),
			'description' => esc_html__( 'Configure site settings of your theme.', 'stag' ),
			'panel'       => 'cluster_options_panel',
			'options'     => array(
				'site_title' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'type'        => 'text',
						'label'       => esc_html__( 'Site Title', 'stag' ),
						'description' => esc_html__( 'Enter the default title for the site header section.', 'stag' ),
					),
				),
				'site_subtitle' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'type'        => 'text',
						'label'       => esc_html__( 'Site Subtitle', 'stag' ),
						'description' => esc_html__( 'Enter the default subtitle for the site header section.', 'stag' ),
					),
				),
				'site_background' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Image_Control',
						'label'         => esc_html__( 'Blog Background Image', 'stag' ),
						'description'   => esc_html__( 'Upload a default background image for the site header section.', 'stag' ),
						'priority'      => 8,
					),
				),
				'site_background_opacity' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'label'       => esc_html__( 'Blog Background Opacity', 'stag' ),
						'description' => esc_html__( 'Choose a default value for background image at the site header section. For no opacity give a value of 100.', 'stag' ),
						'type'        => 'range',
						'input_attrs' => array(
								'min'   => 0,
								'max'   => 100,
								'step'  => 5,
							),
						'priority'    => 9,
						),
				),
				'site_slide_duration' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Slideshow Duration', 'stag' ),
						'description' => esc_html__( 'Enter the duration between slideshows. 1000 is equal to 1 second.', 'stag' ),
						'type'        => 'number',
						'input_attrs' => array(
								'min'   => 0,
								'max'   => 20000,
								'step'  => 50,
							),
						),
				),
				'site_fade_duration' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Fade Duration', 'stag' ),
						'description' => esc_html__( 'Enter the duration between slideshows fade animation.<br>1000 is equal to 1 second.', 'stag' ),
						'type'        => 'number',
						'input_attrs' => array(
								'min'   => 0,
								'max'   => 20000,
								'step'  => 50,
							),
						),
				),
			),
		),

		'portfolio_settings' => array(
			'title'       => esc_html__( 'Portfolio Settings', 'stag' ),
			'description' => esc_html__( 'Configure portfolio settings of your theme.', 'stag' ),
			'panel'       => 'cluster_options_panel',
			'options'     => array(
				'portfolio_style' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Portfolio Style', 'stag' ),
						'description' => esc_html__( 'Select the portfolio filter style for portfolio template. Note: If selecting the Filterable, portfolio expansion will automatically be disabled and will take directly to the single page.', 'stag' ),
						'type'        => 'select',
						'choices'     => array(
							'filterable'  => esc_html__( 'Filterable', 'stag' ),
							'exapandable' => esc_html__( 'Expandable', 'stag' ),
						),
					),
				),
				'portfolio_count' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Portfolio Count', 'stag' ),
						'description' => esc_html__( 'Enter the number of portfolio items for portfolio page.', 'stag' ),
						'type'        => 'number',
						'input_attrs' => array(
							'step' => 1,
							'min' => 1,
							'max' => 50,
						),
					),
				),
				'portfolio_title' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'type'        => 'text',
						'label'       => esc_html__( 'Portfolio Title', 'stag' ),
						'description' => esc_html__( 'Enter the default title for portfolio header section.', 'stag' ),
					),
				),
				'portfolio_subtitle' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'type'        => 'text',
						'label'       => esc_html__( 'Portfolio Subtitle', 'stag' ),
						'description' => esc_html__( 'Enter the default subtitle for portfolio header section.', 'stag' ),
					),
				),
				'portfolio_background' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Image_Control',
						'label'         => esc_html__( 'Portfolio Background Image', 'stag' ),
						'description'   => esc_html__( 'Upload a default background image for the portfolio header section.', 'stag' ),
						'priority'      => 8,
					),
				),
				'portfolio_background_opacity' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'label'       => esc_html__( 'Portfolio Background Opacity', 'stag' ),
						'description' => esc_html__( 'Choose a default value for background image at the portfolio header section. For no opacity give a value of 100.', 'stag' ),
						'type'        => 'range',
						'input_attrs' => array(
								'min'   => 0,
								'max'   => 100,
								'step'  => 5,
							),
						'priority'    => 9,
						),
				),
			),
		),

	);

	/**
	 * Filter the control definitions for the Customizer.
	 *
	 * '[section_id]' => array(
	 * 	   'title' => esc_html__( '[Section Title]', 'stag' ),
	 * 	   'description' => esc_html__( '[Section description]', 'stag' ),
	 * 	   'options' => array(
	 * 		   '[setting-id]' => array(
	 * 			   'setting' => array(
	 *                 [setting-parameter] => [value]
	 *             ),
	 * 			   'control' => array(
	 *                 [control-parameter] => [value]
	 *             ),
	 * 		   ),
	 * 	   ),
	 * ),
	 *
	 * @since 1.0.0.
	 *
	 * @param array    $definitions    The array containing all of the Customizer definitions.
	 */
	$definitions = apply_filters( 'cluster_customizer_definitions', $definitions );

	return $definitions;
}
