/**
 * File customizer.js.
 *
 * global wp
 *
 * Theme Customizer enhancements for a better user experience.
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {
	var api = wp.customize;

	// Site title and description.
	api( 'blogname', function( value ) {
		value.bind( function( to ) {
			if ( $( '#logo a' ).find('> img').length < 1 ) {
				$( '#logo a' ).text( to );
			}
		} );
	} );
	api( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Color.
	api( 'style_background_color', function( value ) {
		value.bind( function( to ) {
			$('body').css('background-color', to);
		} );
	} );
	api( 'style_accent_color', function( value ) {
		value.bind( function( to ) {
			$('.accent-background, .more-link, .button, button, .page-numbers, .nav-links > div, input[type=submit]').css('background-color', to);
			$('.stag-twitter a, .entry-meta a, .entry-content p a, .entry-content h1, .entry-content h2, .entry-content h3, .entry-content h4, .entry-content h5, .entry-content h6, .footer .twitter-feeds li a, footer.copyright .grid-4 a').css('color', to);
		} );
	} );
	api( 'site_background_color', function( value ) {
		value.bind( function( to ) {
			// Must use this to override !important style.
			$('.custom-background.universal')[0].style.setProperty( 'background-color', to, 'important' );
		} );
	} );
	api( 'portfolio_background_color', function( value ) {
		value.bind( function( to ) {
			// Must use this to override !important style.
			$('.single-portfolio .custom-background.universal, .page-template-template-portfolio-php .custom-background.universal')[0].style.setProperty( 'background-color', to, 'important' );
		} );
	} );

	// Opacity
	api( 'site_background_opacity', function( value ) {
		value.bind( function( to ) {
			$('.blog .custom-background.universal .backstretch').css('opacity', to/100);
		} );
	} );
	api( 'portfolio_background_opacity', function( value ) {
		value.bind( function( to ) {
			$('.single-portfolio .custom-background.universal .backstretch, .page-template-template-portfolio-php .custom-background.universal .backstretch').css('opacity', to/100);
		} );
	} );

	// Blog Settings
	api( 'site_title', function( value ) {
		value.bind( function( to ) {
			$( '.blog .custom-background-content h2' ).text( to );
		} );
	} );
	api( 'site_subtitle', function( value ) {
		value.bind( function( to ) {
			$( '.blog .custom-background-content h3' ).text( to );
		} );
	} );

	// Portfolio Settings
	api( 'portfolio_title', function( value ) {
		value.bind( function( to ) {
			$( '.page-template-template-portfolio .custom-background-content h2' ).text( to );
		} );
	} );
	api( 'portfolio_subtitle', function( value ) {
		value.bind( function( to ) {
			$( '.page-template-template-portfolio .custom-background-content h3' ).text( to );
		} );
	} );

	// Footer text
	api( 'general_footer_text', function( value ) {
		value.bind( function( to ) {
			$( 'footer.copyright .grid-4 p' ).html( to );
		} );
	} );

} )( jQuery );
