<?php
/**
 * Cluster functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Cluster
 */

/**
 * The current version of the theme.
 */
define( 'CLUSTER_VERSION', '2.0.2' );

/**
 * The suffix to use for scripts.
 */
if ( ( defined( 'SCRIPT_DEBUG' ) && true === SCRIPT_DEBUG ) ) {
	define( 'CLUSTER_SUFFIX', '' );
} else {
	define( 'CLUSTER_SUFFIX', '.min' );
}

/* Set Max Content Width ---------------------------------------------------*/
if ( ! isset( $content_width ) ) {
	$content_width = 940;
}

/* Set Retina Cookie -------------------------------------------------------*/
global $is_retina;
( isset( $_COOKIE['retina'] ) ) ? $is_retina = true : $is_retina = false;

if ( ! function_exists( 'stag_theme_setup' ) ) {
	/**
	 * Theme setup.
	 *
	 * @return void
	 */
	function stag_theme_setup() {

		load_theme_textdomain( 'stag' );

		/* Register Menus ------------------------------------------------------*/
		register_nav_menu( 'primary-menu', __( 'Primary Menu', 'stag' ) );

		add_theme_support( 'post-thumbnails' );
		add_image_size( 'portfolio-thumbnail', 366, 267, true );

		global $cluster_settings;
		$cluster_settings = new CLUSTER_Settings();

		// Adds RSS feed links to <head> for posts and comments.
		add_theme_support( 'automatic-feed-links' );

		/**
		 * Add cluster specific theme support
		 *
		 * @uses Stagtools
		 * @link http://wordpress.org/plugins/stagtools/
		 * @author Ram Ratan Maurya
		 * @since 1.1
		 */
		add_theme_support( 'stag-portfolio' );

		/* Add support for post formats ----------------------------------------*/
		add_theme_support( 'post-formats', array( 'aside', 'gallery', 'image', 'link', 'quote', 'video', 'audio', 'status', 'chat' ) );

		/**
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 *
		 * @since 2.0.0
		 */
		add_theme_support( 'title-tag' );

		/**
		 * Add support for Gutenberg.
		 *
		 * @since 2.0.2.
		 */
		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'responsive-embeds' );
		add_theme_support( 'editor-styles' );

		add_editor_style( 'assets/css/editor-style.css' );
	}
}
add_action( 'after_setup_theme', 'stag_theme_setup' );

if ( ! function_exists( 'stag_sidebar_init' ) ) {
	/**
	 * Register Sidebars
	 *
	 * @return void
	 */
	function stag_sidebar_init() {

		register_sidebar(
			array(
				'name'          => __( 'Blog Sidebar', 'stag' ),
				'id'            => 'sidebar-main',
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget'  => '</aside>',
				'before_title'  => '<h3 class="widget-title">',
				'after_title'   => '</h3>',
				'description'   => __( 'Blog Widgets Area.', 'stag' ),
			)
		);

		register_sidebar(
			array(
				'name'          => __( 'Homepage Sidebar 1', 'stag' ),
				'id'            => 'sidebar-homepage-1',
				'before_widget' => '<section id="%1$s" class="section-block %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h3 class="section-title">',
				'after_title'   => '</h3>',
				'description'   => __( 'Widgets Area for template Homepage 1.', 'stag' ),
			)
		);

		register_sidebar(
			array(
				'name'          => __( 'Services Sidebar', 'stag' ),
				'id'            => 'sidebar-services',
				'before_widget' => '<div id="%1$s" class="grid-4 %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="service__title">',
				'after_title'   => '</h4>',
				'description'   => __( 'Services Widgets area, use only "Service Box" widget here.', 'stag' ),
			)
		);

		register_sidebar(
			array(
				'name'          => __( 'Footer Widgets', 'stag' ),
				'id'            => 'sidebar-footer',
				'before_widget' => '<div class="grid-4 widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h3 class="widget-title">',
				'after_title'   => '</h3>',
				'description'   => __( 'Widget area for footer', 'stag' ),
			)
		);
	}
}
add_action( 'widgets_init', 'stag_sidebar_init' );

/**
 * Enqueue editor styles for Gutenberg
 */
function cluster_block_editor_styles() {

	/**
	 * Getting & Setting Google Fonts
	 */
	$fonts = cluster_get_google_font_uri();
	if ( '' !== $fonts ) {
		// Enqueue the fonts.
		wp_enqueue_style( 'cluster-google-fonts', $fonts, array(), CLUSTER_VERSION );
	}

	// Cluster Font Icons.
	wp_enqueue_style( 'cluster-icon-font', get_template_directory_uri() . '/assets/fonts/fonts.css', array(), CLUSTER_VERSION );

	$font_header = cluster_get_thememod_value( 'font-headers' );
	$font_body   = cluster_get_thememod_value( 'font-body' );

	$accent_color = cluster_get_thememod_value( 'style_accent_color' );
	wp_add_inline_style(
		'cluster-google-fonts', "
		.edit-post-layout__content{
			--accent-color: {$accent_color};
		}
		.edit-post-visual-editor {
			--font-body: '{$font_body}';
			--font-header: '{$font_header}';
		}"
	);
}
add_action( 'enqueue_block_editor_assets', 'cluster_block_editor_styles' );


/**
 * Register and load scripts.
 *
 * @return void
 */
function stag_enqueue_scripts() {
	if ( ! is_admin() ) {
		global $is_IE;

		// Google fonts.
		$google_request = cluster_get_google_font_uri();

		if ( '' !== $google_request ) {
			// Enqueue the fonts.
			wp_enqueue_style(
				'stag-google-fonts',
				$google_request,
				'',
				CLUSTER_VERSION
			);
		}

		$protocol = ( is_ssl() ) ? 'https:' : 'http:';

		/* Enqueue Styles ---------------------------------------------------*/
		wp_dequeue_style( 'stag-shortcode-styles' );
		wp_enqueue_style( 'shortcode-styles', get_template_directory_uri() . '/assets/css/shortcodes.css', '', CLUSTER_VERSION );

		wp_enqueue_style( 'flexslider', get_template_directory_uri() . '/assets/css/flexslider.css', array(), '2.0' );
		wp_enqueue_style( 'stag-style', get_stylesheet_uri(), array(), CLUSTER_VERSION );

		// Theme option styles
		// Note: in the Customizer, these rules are output inline in the document head,
		// because Ajax calls won't recognize the preview values of settings.
		$version = absint( get_theme_mod( 'version', 0 ) );
		if ( ! is_customize_preview() ) {
			wp_enqueue_style(
				'stag-dynamic-style',
				add_query_arg( 'action', 'cluster-css-rules', admin_url( 'admin-ajax.php' ) ),
				array( 'stag-style' ),
				$version,
				'screen'
			);
		}

		$custom_styles = apply_filters( 'stag_custom_styles', '' );
		wp_add_inline_style( 'stag-style', $custom_styles );

		wp_enqueue_style( 'cluster-icon-font', get_template_directory_uri() . '/assets/fonts/fonts.css', array(), CLUSTER_VERSION );

		/* Register Scripts ---------------------------------------------------*/
		wp_register_script( 'script', get_template_directory_uri() . '/assets/js/jquery.custom.js', array( 'jquery', 'superfish' ), CLUSTER_VERSION, true );
		wp_register_script( 'superfish', get_template_directory_uri() . '/assets/js/superfish.js', array( 'jquery' ), '20180903', true );
		wp_register_script( 'flexslider', get_template_directory_uri() . '/assets/js/jquery.flexslider-min.js', array( 'jquery' ), '2.1', true );
		wp_register_script( 'stag-plugins', get_template_directory_uri() . '/assets/js/plugins.js', array( 'jquery' ), CLUSTER_VERSION, true );
		wp_register_script( 'jplayer', get_template_directory_uri() . '/assets/js/jquery.jplayer.min.js', array( 'jquery' ), '2.9.2', true );
		wp_register_script( 'backstretch', get_template_directory_uri() . '/assets/js/jquery.backstretch.min.js', array( 'jquery' ), '2.0.4', true );
		wp_register_script( 'isotope', get_template_directory_uri() . '/assets/js/isotope.pkgd.min.js', array( 'jquery' ), '3.0.1', true );

		/* Enqueue Scripts ---------------------------------------------------*/
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'script' );
		wp_enqueue_script( 'superfish' );
		wp_enqueue_script( 'flexslider' );

		if ( ! is_page_template( 'template-portfolio.php' ) || ! is_page() ) {
			wp_enqueue_script( 'jplayer' );
		}

		wp_enqueue_script( 'stag-plugins' );
		wp_enqueue_script( 'backstretch' );

		if ( is_page_template( 'template-portfolio.php' ) && 'filterable' === cluster_get_thememod_value( 'portfolio_style' ) ) {
			wp_enqueue_script( 'isotope' );
		}

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' ); // loads the javascript required for threaded comments.
		}

		wp_localize_script(
			'script', 'stag', array(
				'ajaxurl'  => admin_url( 'admin-ajax.php' ),
				'nonce'    => wp_create_nonce( 'stag-ajax' ),
				'menuIcon' => ( function_exists( 'stag_icon' ) ) ? stag_icon( array( 'icon' => 'reorder' ) ) : '',
				'gateway'  => get_template_directory_uri() . '/includes/gateway.php',
			)
		);

		// Add tracking code.
		$tracking_code = cluster_get_thememod_value( 'general_tracking_code' );
		if ( '' !== $tracking_code ) {
			wp_add_inline_script( 'script', $tracking_code );
		}
	}
}
add_action( 'wp_enqueue_scripts', 'stag_enqueue_scripts' );

/**
 * Admin Scripts.
 *
 * @return void
 */
function stag_admin_enqueue_scripts() {
	wp_enqueue_script( 'stag-custom-admin', get_template_directory_uri() . '/includes/js/custom.admin.js', 'jquery', CLUSTER_VERSION );
}
add_action( 'admin_enqueue_scripts', 'stag_admin_enqueue_scripts' );

/**
 * Pagination.
 *
 * @return mixed|bool
 */
function pagination() {
	global $wp_query;
	$total_pages = $wp_query->max_num_pages;
	$big         = 999999999;
	if ( $total_pages > 1 ) {
		if ( $total_pages > 1 ) {
			$current_page = max( 1, get_query_var( 'paged' ) );
			$return       = paginate_links(
				array(
					'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
					'format'    => '/page/%#%',
					'current'   => $current_page,
					'total'     => $total_pages,
					'prev_next' => false,
				)
			);
			echo "<div class='pages'>{$return}</div>"; // WPCS: XSS ok.
		}
	} else {
		return false;
	}
}

function stag_paging_nav() {
	global $wp_query;

	// Don't print empty markup if there's only one page.
	if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) ) {
		return;
	}
	?>
	<nav class="navigation paging-navigation" role="navigation">
		<?php echo pagination(); ?>
		<div class="nav-links">

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-previous"><?php previous_posts_link( __( '<i class="icon icon-arrow-left"></i>', 'stag' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-next"><?php next_posts_link( __( '<i class="icon icon-arrow-right"></i>', 'stag' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}

/**
 * Stag Comment Styling.
 *
 * @param object $comment
 * @param array  $args
 * @param [type] $depth
 * @return void
 */
function stag_comments( $comment, $args, $depth ) {

	$isByAuthor = false;

	if ( $comment->comment_author_email === get_the_author_meta( 'email' ) ) {
			$isByAuthor = true;
	}

	$GLOBALS['comment'] = $comment;
	?>
	 <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		 <div id="comment-<?php comment_ID(); ?>" class="the-comment">

		 <div class="comment-body clearfix">
				<div class="avatar-wrap">
					<?php
					global $is_retina;
					if ( $is_retina ) {
						echo get_avatar( $comment, $size = '140' );
					} else {
						echo get_avatar( $comment, $size = '70' );
					}
					?>
				</div>
				<div class="comment-area">
						<div class="row">
							<?php
							comment_reply_link(
								array_merge(
									$args, array(
										'depth'     => $depth,
										'max_depth' => $args['max_depth'],
									)
								)
							);
							?>
							<p class="comment-author"><?php echo get_comment_author_link(); ?></p>
							<time datetime="<?php comment_time( 'c' ); ?>" class="comment-date">
								<?php echo human_time_diff( get_comment_time( 'U' ), current_time( 'timestamp' ) ) . ' ' . __( 'ago', 'stag' ); ?>
							</time>
						</div>
						<?php if ( '0' === $comment->comment_approved ) : ?>
							 <em class="moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'stag' ); ?></em>
						<?php endif; ?>
						<div class="comment-text">
							<?php comment_text(); ?>
						</div>
				</div>
			</div>

		 </div>
	 </li>

	<?php
}

function stag_list_pings( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	?>
	<li id="comment-<?php comment_ID(); ?>"><?php comment_author_link(); ?>
	<?php
}


/* A little math stuff ---------------------------------------------------*/
function is_multiple( $number, $multiple ) {
	return ( $number % $multiple ) === 0;
}

/*
-----------------------------------------------------------------------------------*/
/*
  Allow shortcodes in Text Widgets
/*-----------------------------------------------------------------------------------*/
add_filter( 'widget_text', 'shortcode_unautop' );
add_filter( 'widget_text', 'do_shortcode' );

/**
 * @package Cluster
 * @param bool $postid - Post ID
 * @return Audio Player
 */
function stag_audio_player( $postid ) {
	$mp3 = get_post_meta( $postid, '_stag_audio_mp3', true );
	$ogg = get_post_meta( $postid, '_stag_audio_oga', true );

	// I can guarantee you some safety.
	if ( '' === $mp3 && '' === $ogg ) {
		return;
	}

	?>

	<script type="text/javascript">

	jQuery(document).ready(function($){
		if( $().jPlayer ){
			$('#jquery-jplayer-audio-<?php echo $postid; ?>').jPlayer({
				ready: function(){
					$(this).jPlayer("setMedia", {
						<?php if ( '' !== $mp3 ) : ?>
						mp3: "<?php echo $mp3; ?>",
						<?php endif; ?>
						<?php if ( '' !== $ogg ) : ?>
						oga: "<?php echo $ogg; ?>",
						<?php endif; ?>
						end: ""
					});
				},
				play: function() { // To avoid both jPlayers playing together.
					$(this).jPlayer("pauseOthers");
				},
				swfPath: "<?php echo get_template_directory_uri(); ?>/assets/js",
				cssSelectorAncestor: "#jp-audio-interface-<?php echo $postid; ?>",
				supplied: "
				<?php
				if ( $ogg != '' ) :
					?>
					oga,<?php endif; ?>
					<?php
					if ( $mp3 != '' ) :
						?>
					mp3<?php endif; ?>",
			});
		}
	});

	</script>

	<div id="jp-container-<?php echo $postid; ?>" class="jp-audio">
		<div class="jp-type-single">
			<div id="jquery-jplayer-audio-<?php echo $postid; ?>" class="jp-jplayer"></div>
			<div id="jp-audio-interface-<?php echo $postid; ?>" class="jp-interface">
					<ul class="jp-controls">
							<li><a href="#" class="jp-play" tabindex="1" title="play"><i class="icon icon-play"></i></a></li>
							<li><a href="#" class="jp-pause" tabindex="1" title="pause"><i class="icon icon-pause"></i></a></li>
							<li><a href="#" class="jp-mute" tabindex="1" title="mute"><i class="icon icon-volume"></i></a></li>
							<li><a href="#" class="jp-unmute" tabindex="1" title="unmute"><i class="icon icon-volume"></i></a></li>
							<li><a href="#" class="jp-duration" tabindex="1" title="duration"></a></li>
					</ul>
					<div class="jp-progress">
							<div class="jp-seek-bar">
									<div class="jp-play-bar"></div>
							</div>
					</div>
					<div class="jp-volume-bar">
							<div class="jp-volume-bar-value"></div>
					</div>
			</div>
		</div>
	</div>

	<?php

}

/**
 * @package Cluster
 * @param bool $postid - Post ID
 * @return Video Player
 */
function stag_video_player( $postid ) {
	$m4v = get_post_meta( get_the_ID(), '_stag_video_m4v', true );
	$ogv = get_post_meta( get_the_ID(), '_stag_video_ogv', true );

	if ( '' === $m4v && '' === $ogv ) {
		return;
	}

	?>
	<script type="text/javascript">
	jQuery(document).ready(function($){

		if( $().jPlayer ) {
			$("#jquery-jplayer-video-<?php echo $postid; ?>").jPlayer({
				ready: function(){
					$(this).jPlayer("setMedia",{
						<?php if ( '' !== $m4v ) : ?>
						m4v: "<?php echo $m4v; ?>",
						<?php endif; ?>
						<?php if ( '' !== $ogv ) : ?>
						ogv: "<?php echo $ogv; ?>",
						<?php endif; ?>
					});
				},
				size: {
					cssClass: "jp-video-normal",
					width: "100%",
				},
				autohide:{
					restored: false,
					full: true
				},
				play: function() { // To avoid both jPlayers playing together.
					$('#jp-video-container-<?php echo $postid; ?> .jp-jplayer').css('padding-bottom', '56.25%');
				},
				swfPath: "<?php echo get_template_directory_uri(); ?>/assets/js",
				cssSelectorAncestor: "#jp-video-container-<?php echo $postid; ?>",
				supplied: "
				<?php
				if ( '' === $m4v ) :
					?>
					m4v, <?php endif; ?>
					<?php
					if ( '' !== $ogv ) :
						?>
 ogv<?php endif; ?>"
			});
		}

	});
	</script>

	<div id="jp-video-container-<?php echo $postid; ?>" class="jp-video jp-video-normal">
			<div class="jp-type-single">
					<div id="jquery-jplayer-video-<?php echo $postid; ?>" class="jp-jplayer" data-orig-width="700" data-orig-height="300"></div>
					<div class="jp-gui">
					<div id="jp-video-interface-<?php echo $postid; ?>" class="jp-interface">
							<ul class="jp-controls">
									<li><a href="#" class="jp-play" tabindex="1"><i class="icon-play"></i></a></li>
									<li><a href="#" class="jp-pause" tabindex="1"><i class="icon icon-pause"></i></a></li>
									<li><a href="#" class="jp-mute" tabindex="1"><i class="icon icon-volume"></i></a></li>
									<li><a href="#" class="jp-unmute" tabindex="1"><i class="icon icon-volume"></i></a></li>
									<li><a href="#" class="jp-duration" tabindex="1" title="duration">time</a></li>
							</ul>
							<div class="jp-progress">
									<div class="jp-seek-bar">
											<div class="jp-play-bar"></div>
									</div>
							</div>
							<div class="jp-volume-bar">
									<div class="jp-volume-bar-value"></div>
							</div>
					</div>
			</div>
			</div>
	</div>

	<?php
}

/**
 * Format custom date.
 *
 * @deprecated 1.7
 *
 * @return mixed Formatted date.
 */
function stag_date( $arg, $data = null ) {
		$return = date_i18n( $arg, strtotime( $data ) );
		return $return;
}

function stag_portfolio_load_more() {
	if ( ! wp_verify_nonce( $_POST['nonce'], 'stag-ajax' ) ) {
		die( 'Invalid nonce' );
	}
	if ( ! is_numeric( $_POST['page'] ) || $_POST['page'] < 0 ) {
		die( 'Invalid page' );
	}

		$query_args = array(
			'post_type'      => 'portfolio',
			'posts_per_page' => cluster_get_thememod_value( 'portfolio_count' ),
			'paged'          => $_POST['page'],
			'meta_query'     => array(
				array( 'key' => '_thumbnail_id' ),
			),
		);

		$unique_skills = array();

		ob_start();
		$query = new WP_Query( $query_args );

	while ( $query->have_posts() ) :
		$query->the_post();

		if ( ! has_post_thumbnail() ) {
			continue;
		}

		$skills = get_the_terms( get_the_ID(), 'skill' );
		$class  = 'grid-4 portfolio';

		if ( is_array( $skills ) ) {
			$unique_skills = wp_list_pluck( $skills, 'slug' );
			$class        .= ' ' . implode( ' ', $unique_skills );
		}

		?>

		<div <?php post_class( $class ); ?>>
			<div class="overlay">
				<h3 class="entry-title"><a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php printf( esc_html__( 'Permanent Link to %s', 'stag' ), get_the_title() ); ?>"> <?php the_title(); ?></a></h3>
				<div class="portfolio-navigation">
					<a href="<?php the_permalink(); ?>" class="accent-background portfolio-trigger" data-id="<?php the_ID(); ?>"><i class="icon-eye"></i></a>
					<a href="<?php the_permalink(); ?>" class="accent-background" rel="bookmark" title="<?php printf( esc_html__( 'Permanent Link to %s', 'stag' ), get_the_title() ); ?>"><i class="icon-post-link"></i></a>
				</div>
			</div>
			<?php the_post_thumbnail( 'full' ); ?>
		</div>

		<?php

		endwhile;

		wp_reset_postdata();

		$content = ob_get_contents();

		ob_end_clean();

		echo wp_json_encode(
			array(
				'pages'      => $query->max_num_pages,
				'content'    => $content,
				'new_skills' => wp_json_encode( array_values( array_unique( $unique_skills ) ) ),
			)
		);
		exit;
}
add_action( 'wp_ajax_stag_portfolio_load_more', 'stag_portfolio_load_more' );
add_action( 'wp_ajax_nopriv_stag_portfolio_load_more', 'stag_portfolio_load_more' );

/**
 * Check if there is any third party plugin active
 *
 * @since 1.1
 */
function stag_check_third_party_seo() {
	include_once ABSPATH . 'wp-admin/includes/plugin.php';

	if ( is_plugin_active( 'headspace2/headspace.php' ) ) {
		return true;
	}
	if ( is_plugin_active( 'all-in-one-seo-pack/all_in_one_seo_pack.php' ) ) {
		return true;
	}
	if ( is_plugin_active( 'wordpres-seo/wp-seo.php' ) ) {
		return true;
	}

	return false;
}

/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 *
 * @since 1.4
 */
function stag_required_plugins() {
	$plugins = array(
		array(
			'name'     => 'StagTools',
			'slug'     => 'stagtools',
			'required' => true,
		),
		array(
			'name'     => 'Stag Blocks',
			'slug'     => 'stag-blocks',
			'required' => false,
		),
		array(
			'name'         => 'Envato Market',
			'slug'         => 'envato-market',
			'source'       => 'https://envato.github.io/wp-envato-market/dist/envato-market.zip',
			'required'     => false,
			'version'      => '2.0.1',
			'external_url' => 'https://github.com/envato/wp-envato-market/',
		),

	);

	tgmpa( $plugins );
}
add_action( 'tgmpa_register', 'stag_required_plugins' );

/**
 * Add dynamic CSS to WordPress editor.
 *
 * @param  array $mceInit An array of keys.
 * @return array
 */
function stag_wp_editor_dynamic_styles( $mceInit ) {
	$styles  = 'body.mce-content-body h1,body.mce-content-body h2,body.mce-content-body h3,body.mce-content-body h4,body.mce-content-body h5,body.mce-content-body h6 { color: ' . cluster_get_thememod_value( 'style_accent_color' ) . '; }';
	$styles .= 'body.mce-content-body a.button.alt, body.mce-content-body a.button, body.mce-content-body button { background-color: ' . cluster_get_thememod_value( 'style_accent_color' ) . '; }';
	$styles .= 'body.mce-content-body { font-family: ' . cluster_get_thememod_value( 'font-body' ) . '; }';
	$styles .= 'body.mce-content-body h1,body.mce-content-body h2,body.mce-content-body h3,body.mce-content-body h4,body.mce-content-body h5,body.mce-content-body h6 { font-family: ' . cluster_get_thememod_value( 'font-headers' ) . '; }';
	if ( isset( $mceInit['content_style'] ) ) {
		$mceInit['content_style'] .= ' ' . $styles . ' ';
	} else {
		$mceInit['content_style'] = $styles . ' ';
	}
	return $mceInit;
}
add_filter( 'tiny_mce_before_init', 'stag_wp_editor_dynamic_styles' );

if ( ! function_exists( 'stag_content_width' ) ) :
	/**
	 * Set the content width based on the current layout.
	 *
	 * @since 1.6.3
	 *
	 * @return void
	 */
	function stag_content_width() {
		global $content_width;

		if ( is_page_template( 'template-full-width.php' ) || 'layout-1cf' === cluster_get_thememod_value( 'style_main_layout' ) ) {
			$content_width = 1170;
		}
	}
endif;

add_action( 'template_redirect', 'stag_content_width' );

/**
 * Custom template tags for this theme.
 */
require_once get_parent_theme_file_path() . '/includes/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require_once get_parent_theme_file_path() . '/includes/extras.php';

/**
 * Load Jetpack compatibility file.
 */
require_once get_parent_theme_file_path() . '/includes/jetpack.php';

/**
 * Widget related files.
 */
require_once get_parent_theme_file_path() . '/includes/class-widgetized-pages.php';
require_once get_parent_theme_file_path() . '/includes/widgets/widget-clients.php';
require_once get_parent_theme_file_path() . '/includes/widgets/widget-latest-post.php';
require_once get_parent_theme_file_path() . '/includes/widgets/widget-portfolio.php';
require_once get_parent_theme_file_path() . '/includes/widgets/widget-services.php';
require_once get_parent_theme_file_path() . '/includes/widgets/widget-services-section.php';
require_once get_parent_theme_file_path() . '/includes/widgets/widget-static-content.php';
require_once get_parent_theme_file_path() . '/includes/widgets/widget-featured-portfolio.php';

/**
 * Load customizer files.
 */
require_once get_parent_theme_file_path() . '/includes/customizer/settings.php';
require_once get_parent_theme_file_path() . '/includes/customizer/css.php';
require_once get_parent_theme_file_path() . '/includes/customizer/style.php';
require_once get_parent_theme_file_path() . '/includes/customizer/load.php';

/**
 * Include metabox and other files
 */
require_once get_template_directory() . '/includes/_init.php';

/**
* Include theme updater file
*/
//require_once get_template_directory() . '/includes/updater/theme-updater.php';
