<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * @package Cluster
 */

/**
 * Add browser body classes.
 *
 * @param  array $classes An array containing classes for body
 * @return void
 */
function stag_body_class( $classes ) {
	global $is_lynx, $is_gecko, $is_IE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;

	if ( $is_lynx ) $classes[] = 'lynx';
	elseif ( $is_gecko ) $classes[] = 'gecko';
	elseif ( $is_opera ) $classes[] = 'opera';
	elseif ( $is_NS4 ) $classes[] = 'ns4';
	elseif ( $is_safari ) $classes[] = 'safari';
	elseif ( $is_chrome ) $classes[] = 'chrome';
	elseif ( $is_IE ) {
		$browser = $_SERVER['HTTP_USER_AGENT'];
		$browser = substr( "$browser", 25, 8);
		if ( $browser == "MSIE 7.0"  ) {
			$classes[] = 'ie7';
			$classes[] = 'ie';
		} elseif ( $browser == "MSIE 6.0" ) {
			$classes[] = 'ie6';
			$classes[] = 'ie';
		} elseif ( $browser == "MSIE 8.0" ) {
			$classes[] = 'ie8';
			$classes[] = 'ie';
		} elseif ( $browser == "MSIE 9.0" ) {
			$classes[] = 'ie9';
			$classes[] = 'ie';
		} else {
			$classes[] = 'ie';
		}
	}
	else $classes[] = 'unknown';

	if ( $is_iphone ) $classes[] = 'iphone';

	return $classes;
}
add_filter( 'body_class', 'stag_body_class' );

/**
 * Check if theme is just activated.
 *
 * @return bool
 */
function stag_is_theme_activated(){
	global $pagenow;
	if ( is_admin() && isset($_GET['activated'] ) && $pagenow == "themes.php" )
		return true;
	return false;
}


/*---------------------------------------------------------*/
/* Filters that allow shortcodes in Text widgets
/*---------------------------------------------------------*/
add_filter( 'widget_text', 'shortcode_unautop' );
add_filter( 'widget_text', 'do_shortcode' );


/*---------------------------------------------------------*/
/* Remove generator for security
/*---------------------------------------------------------*/
remove_action( 'wp_head', 'wp_generator' );

/**
 * Output main layout class
 *
 * @param  array $classes body class.
 * @return array
 */
function stag_style_main_layout( $classes ) {
	$classes[] = cluster_get_thememod_value( 'style_main_layout' );
	return $classes;
}
add_filter( 'body_class', 'stag_style_main_layout' );

/**
 * Set posts per page for portfolio to unlimited.
 *
 * @param object $query Main query.
 * @return void
 */
function cluster_set_posts_per_page_for_portfolio( $query ) {
	if ( ( ! is_admin() && $query->is_main_query() ) && is_post_type_archive( 'portfolio' ) || is_tax( 'skill' ) ) {
		$query->set( 'posts_per_page', cluster_get_thememod_value( 'portfolio_count' ) );
	}
}

add_action( 'pre_get_posts', 'cluster_set_posts_per_page_for_portfolio' );
